@@ -24,7 +24,7 @@ from .compat import get_opt
 
 LOG = logging.getLogger("avocado.app")
 
-basic_program_requirements = ['xz', 'tcpdump', 'nc', 'ip', 'arping']
+basic_program_requirements = ['xz', 'tcpdump', 'nc', 'ip', 'arping', 'diff']
 
 recommended_programs = {'qemu': [('qemu-kvm', 'kvm'), ('qemu-img',),
                                  ('qemu-io',), ('virsh',)],
@@ -305,8 +305,7 @@ def sync_download_dir(interactive):
 
 
 def create_guest_os_cfg(t_type):
-    root_dir = data_dir.get_root_dir()
-    guest_os_cfg_dir = os.path.join(root_dir, 'shared', 'cfg', 'guest-os')
+    guest_os_cfg_dir = os.path.join(data_dir.get_shared_dir(), 'cfg', 'guest-os')
     guest_os_cfg_path = data_dir.get_backend_cfg_path(t_type, 'guest-os.cfg')
     guest_os_cfg_file = open(guest_os_cfg_path, 'w')
     get_directory_structure(guest_os_cfg_dir, guest_os_cfg_file, "Guest")
@@ -357,7 +356,7 @@ def create_host_os_cfg(options):
         if hasattr(cpu, 'get_family'):
             try:
                 family = cpu.get_family()
-            except NotImplementedError:
+            except Exception:
                 pass
         cpu_version = cpu.get_version() if hasattr(cpu, 'get_version') else None
 
