@@ -15,6 +15,8 @@ except ImportError:
     from urllib2 import ProxyHandler, build_opener, install_opener
 
 import aexpect
+from aexpect import remote
+
 from avocado.utils import process as a_process
 from avocado.utils import crypto
 from avocado.utils import path
@@ -38,7 +40,6 @@ from virttest import utils_libguestfs
 from virttest import qemu_storage
 from virttest import utils_libvirtd
 from virttest import utils_split_daemons
-from virttest import remote
 from virttest import data_dir
 from virttest import utils_net
 from virttest import nfs
@@ -928,12 +929,13 @@ def preprocess(test, params, env):
     # done as root, here we do a check whether
     # we satisfy that condition, if not try to make it off
     # otherwise throw TestError with respective error message
+    cpu_family = "unknown"
     try:
         cpu_family = cpu_utils.get_family() if hasattr(cpu_utils, 'get_family') else cpu_utils.get_cpu_arch()
-    except NotImplementedError:
-        cpu_family = "unknown"
+    except Exception:
+        logging.warning("Could not get host cpu family")
     migration_setup = params.get("migration_setup", "no") == "yes"
-    if "power" in cpu_family:
+    if cpu_family is not None and "power" in cpu_family:
         pvr_cmd = "grep revision /proc/cpuinfo | awk '{print $3}' | head -n 1"
         pvr = float(a_process.system_output(pvr_cmd, shell=True).strip())
         power9_compat = "yes" == params.get("power9_compat", "no")
@@ -1682,11 +1684,12 @@ def postprocess(test, params, env):
 
     libvirtd_inst = None
     vm_type = params.get("vm_type")
+    cpu_family = "unknown"
     try:
         cpu_family = cpu_utils.get_family() if hasattr(cpu_utils, 'get_family') else cpu_utils.get_cpu_arch()
-    except NotImplementedError:
-        cpu_family = "unknown"
-    if "power" in cpu_family:
+    except Exception:
+        logging.warning("Could not get host cpu family")
+    if cpu_family is not None and "power" in cpu_family:
         pvr_cmd = "grep revision /proc/cpuinfo | awk '{print $3}' | head -n 1"
         pvr = float(a_process.system_output(pvr_cmd, shell=True).strip())
         # Restore SMT changes in the powerpc host is set
