@@ -13,6 +13,8 @@ try:
 except ImportError:
     import ConfigParser
 
+from aexpect import remote
+
 from avocado.core import exceptions
 from avocado.utils import astring
 from avocado.utils import iso9660
@@ -24,7 +26,6 @@ from virttest import virt_vm
 from virttest import asset
 from virttest import utils_disk
 from virttest import qemu_monitor
-from virttest import remote
 from virttest import syslog_server
 from virttest import http_server
 from virttest import data_dir
@@ -177,7 +178,7 @@ class UnattendedInstallConfig(object):
                         'virtio_storage_path', 'virtio_network_path',
                         'virtio_balloon_path', 'virtio_viorng_path',
                         'virtio_vioser_path', 'virtio_pvpanic_path',
-                        'virtio_vioinput_path',
+                        'virtio_vioinput_path', 'virtio_viofs_path',
                         'virtio_oemsetup_id',
                         'virtio_network_installer_path',
                         'virtio_balloon_installer_path',
@@ -531,7 +532,7 @@ class UnattendedInstallConfig(object):
                       self.virtio_storage_path, self.virtio_network_path,
                       self.virtio_balloon_path, self.virtio_viorng_path,
                       self.virtio_vioser_path, self.virtio_pvpanic_path,
-                      self.virtio_vioinput_path]
+                      self.virtio_vioinput_path, self.virtio_viofs_path]
 
             # XXX: Force to replace the drive letter which loaded the
             # virtio driver by the specified letter.
