@@ -24,6 +24,7 @@ from avocado.utils.service import SpecificServiceManager
 
 from virttest import error_context
 from virttest import utils_numeric
+from virttest import remote
 
 PARTITION_TABLE_TYPE_MBR = "msdos"
 PARTITION_TABLE_TYPE_GPT = "gpt"
@@ -156,7 +157,8 @@ def umount(src, dst, fstype=None, verbose=False, session=None):
         fuser_cmd = "fuser -km %s" % dst
         umount_cmd = "umount %s" % dst
         if session:
-            session.cmd_output_safe(fuser_cmd)
+            if not isinstance(session, remote.VMManager):
+                session.cmd_output_safe(fuser_cmd)
             return session.cmd_status(umount_cmd, safe=True) == 0
         process.system(fuser_cmd, ignore_status=True, verbose=True, shell=True)
         return process.system(umount_cmd, ignore_status=True, verbose=True) == 0
@@ -790,6 +792,36 @@ def get_disk_size(session, os_type, did):
         return get_disk_size_windows(session, did)
 
 
+def get_drive_letters(session, did):
+    """
+    Get drive letters of specified disk in windows guest.
+
+    :param session: Windows VM session.
+    :type session: aexpect.ShellSession
+    :param did: The disk index.
+    :type did: str
+    :return: The drive letters.
+    :rtype: list
+    """
+    disk_script = "disk_" + ''.join(
+        random.sample(string.ascii_letters + string.digits, 4))
+    select_cmd = "echo select disk %s > %s " % (did, disk_script)
+    detail_cmd = "echo detail disk >> %s" % disk_script
+    diskpart_cmd = "diskpart /s %s" % disk_script
+    cmd = ' && '.join((select_cmd, detail_cmd, diskpart_cmd))
+    output = session.cmd(cmd)
+
+    letter_offset = 0
+    searched_ret = re.search(r"(.*Volume\s+.*Ltr.*)", output, re.I | re.M)
+    if searched_ret:
+        letter_offset = searched_ret.group(1).index('Ltr') + 1
+
+    if letter_offset:
+        vol_details = re.findall(r"(.*Volume\s+\d+.*Partition.*)", output, re.I | re.M)
+        return [_[letter_offset] for _ in vol_details if _[letter_offset].isalpha()]
+    return []
+
+
 def set_drive_letter(session, did, partition_no=1):
     """
     set drive letter for partition in windows guest.
@@ -1046,6 +1078,38 @@ def get_disk_by_serial(serial_str, session=None):
             return disk
 
 
+def check_remote_vm_disks(params):
+    """
+    Check disks in remote vm are working well with I/O.
+
+    :param params: the dict used for parameters
+    """
+    remote_vm_obj = remote.VMManager(params)
+    remote_vm_obj.check_network()
+    remote_vm_obj.setup_ssh_auth()
+    disks = get_linux_disks(remote_vm_obj, False)
+    logging.debug("Get disks in remote VM: %s", disks)
+
+    for disk in disks.keys():
+        linux_disk_check(remote_vm_obj, disk)
+
+
+def dd_data_to_vm_disk(session, disk, bs='1M', seek='0', count='100'):
+    """
+    Generate some random data to a vm disk
+
+    :param session: The vm session we'll use
+    :param disk: The disk of the vm we'll use
+    :param bs: The 'bs' param of the 'dd' command
+    :param seek: The 'seek' param of the 'dd' command
+    :param count: The 'count' param of the 'dd' command
+    """
+    dd_cmd = "dd if=/dev/urandom of=%s bs=%s seek=%s count=%s; sync"
+    dd_cmd %= (disk, bs, seek, count)
+    output = session.cmd_output(dd_cmd).strip()
+    logging.debug("Using dd to generate data to %s: %s", disk, output)
+
+
 class Disk(object):
 
     """
