@@ -29,11 +29,12 @@ import time
 import select
 
 import aexpect
+from aexpect import remote
+
 from avocado.utils import path
 from avocado.utils import process
 
 from . import propcan
-from . import remote
 from . import utils_misc
 
 
